"use strict";

exports.__esModule = true;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * @class TimeConverter
 * @author Yago Estévez
 * @description A tiny class to convert a given time into different units.
 */
var TimeConverter = function () {
  function TimeConverter() {
    _classCallCheck(this, TimeConverter);
  }

  /**
   * @function getFullTime() Gets the time in milliseconds and returns its
   *  equivalent in hours, minutes, seconds and milliseconds. 
   * @param {number} ms - a time expressed in milliseconds. 
   * @returns The function returns an object with the following structure:
   *  { hours: ##, minutes: ##, seconds: ##, millis: # }.
   */
  TimeConverter.prototype.getFullTime = function getFullTime(ms, leftPadding) {
    var millis = parseInt(ms % 1000 / 100);
    var seconds = parseInt(ms / 1000 % 60);
    var minutes = parseInt(ms / (1000 * 60) % 60);
    var hours = parseInt(ms / (1000 * 60 * 60));

    if (leftPadding) return this.getLeftPadding(leftPadding, hours, minutes, seconds, millis, ms);

    return { hours: hours, minutes: minutes, seconds: seconds, millis: millis, totalMs: ms };
  };

  TimeConverter.prototype.getMilliseconds = function getMilliseconds(time) {
    return Number(time.hours * 3600000 + time.minutes * 60000 + time.seconds * 1000 + time.millis);
  };

  TimeConverter.prototype.getLeftPadding = function getLeftPadding(leftPadding, hours, minutes, seconds, millis, ms) {
    hours = hours < 10 ? leftPadding + hours : hours;
    minutes = minutes < 10 ? leftPadding + minutes : minutes;
    seconds = seconds < 10 ? leftPadding + seconds : seconds;

    return { hours: hours, minutes: minutes, seconds: seconds, millis: millis, totalMs: ms };
  };

  return TimeConverter;
}();

exports.default = TimeConverter;
module.exports = exports["default"];